@@ -54,16 +54,20 @@ class LabelSmoothingLoss(nn.Module):
 
 @box.register(tag='model')
 class L2Loss(nn.Module):
-    with open(str(Path(__file__).parent / 'schema' / 'l2_loss_config.json')) as f:
-        schema = json.load(f)
-
     def __init__(self, config: L2LossConfig = None):
         super().__init__()
+        self.normalize = config.normalize
 
     def forward(self, predict: torch.Tensor, target: torch.Tensor):
-        return predict.sub(target).pow(2).sum(1).mean(0).div(2)
+        if self.normalize:
+            return (predict - target).pow(2).mean()
+        else:
+            return (predict - target).pow(2).sum(1).mean(0) / 2
 
     @classmethod
     def factory(cls, config: dict = None):
         jsonschema.validate(config or {}, cls.schema)
         return cls(config=L2LossConfig(config))
+
+    with open(str(Path(__file__).parent / 'schema' / 'l2_loss_config.json')) as f:
+        schema = json.load(f)
